import { SpamPolicyDeleteRequest, SpamPolicyPostRequest, MailcowResponse, SpamPolicyGetRequest, SpamPolicy } from '../types';
import MailcowClient from '../index';
/**
 * Interface for all antispam policies.
 */
export interface AntiSpamEndpoints {
    /**
     * Endpoint for getting antispam policies.
     * @param payload - The get payload.
     */
    get(payload: SpamPolicyGetRequest): Promise<SpamPolicy[]>;
    /**
     * Endpoint for creating antispam policies.
     * @param payload - The creation payload.
     */
    create(payload: SpamPolicyPostRequest): Promise<MailcowResponse>;
    /**
     * Endpoint for deleting antispam policies.
     * @param payload - The deletion payload.
     */
    delete(payload: SpamPolicyDeleteRequest): Promise<MailcowResponse>;
}
/**
 * Binder function between the MailcowClient class and the AntiSpamEndpoints
 * @param bind - The MailcowClient to bind.
 * @internal
 */
export declare function antiSpamEndpoints(bind: MailcowClient): AntiSpamEndpoints;
