import MailcowClient from '../index';
import { ACMELog, ADLog, APILog, DCLog, NFLog, PFLog, RLLog, RSLog, SGLog, WDLog } from '../types';
export interface LogEndpoints {
    /**
     * Endpoint for returning ACME Logs.
     * @param count - The number of logs to return.
     */
    acme(count: number): Promise<ACMELog[]>;
    /**
     * Endpoint for returning API Logs.
     * @param count - The number of logs to return.
     */
    api(count: number): Promise<APILog[]>;
    /**
     * Endpoint for returning Autodiscover Logs.
     * @param count - The number of logs to return.
     */
    autodiscover(count: number): Promise<ADLog[]>;
    /**
     * Endpoint for returning dovecot Logs.
     * @param count - The number of logs to return.
     */
    dovecot(count: number): Promise<DCLog[]>;
    /**
     * Endpoint for returning Netfilter Logs.
     * @param count - The number of logs to return.
     */
    netfilter(count: number): Promise<NFLog[]>;
    /**
     * Endpoint for returning Postfix Logs.
     * @param count - The number of logs to return.
     */
    postfix(count: number): Promise<PFLog[]>;
    /**
     * Endpoint for returning Rate limited Logs.
     * @param count - The number of logs to return.
     */
    ratelimited(count: number): Promise<RLLog[]>;
    /**
     * Endpoint for returning Rspamd Logs.
     * @param count - The number of logs to return.
     */
    rspamd(count: number): Promise<RSLog[]>;
    /**
     * Endpoint for returning SOGo Logs.
     * @param count - The number of logs to return.
     */
    sogo(count: number): Promise<SGLog[]>;
    /**
     * Endpoint for returning Watchdog Logs.
     * @param count - The number of logs to return.
     */
    watchdog(count: number): Promise<WDLog[]>;
}
export declare function logEndpoints(bind: MailcowClient): LogEndpoints;
