"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.mailboxEndpoints = void 0;
const request_factory_1 = require("../request-factory");
/**
 * Binder function between the MailcowClient class and the MailboxEndpoints
 * @param bind - The MailcowClient to bind.
 * @internal
 */
function mailboxEndpoints(bind) {
    return {
        create(payload) {
            return bind.requestFactory.post('/api/v1/add/mailbox', payload);
        },
        delete(payload) {
            return bind.requestFactory.post('/api/v1/delete/mailbox', payload.mailboxes);
        },
        edit(payload) {
            return bind.requestFactory.post('/api/v1/edit/mailbox', payload);
        },
        get(mailbox = 'all') {
            return (0, request_factory_1.wrapPromiseToArray)(bind.requestFactory.get(`/api/v1/get/mailbox/${mailbox}`));
        },
        editPushover(payload) {
            return bind.requestFactory.post('/api/v1/edit/pushover', payload);
        },
        editQuarantine(payload) {
            return bind.requestFactory.post('/api/v1/edit/quarantine_notification', payload);
        },
        editSpamScore(payload) {
            return bind.requestFactory.post('/api/v1/edit/spam-score', payload);
        },
        editUserACL(payload) {
            return bind.requestFactory.post('/api/v1/edit/user-acl', payload);
        },
        getActiveUserSieve(mailbox) {
            return bind.requestFactory.get(`/api/v1/get/active-user-sieve/${mailbox}`);
        }
    };
}
exports.mailboxEndpoints = mailboxEndpoints;
//# sourceMappingURL=mailbox-endpoint.js.map